;--------------------------------------------------------------------
; Proc name : WildCardQueryFormat()
; Syntax    : WildCardQueryFormat( str.a )
;   where
;      str.a - string to format
;
; Purpose   : This procedure formats a string to be used in a Paradox
;             Query. The string may contain the Wildcards ".." and "@" 
;             and it may also contain reserved words or any combination 
;             of these. This will also  work for various punctuation 
;             marks in strings.
;
;             Entering in a query search for [Name]   MAX.. 
;             would produce a problem. but entering the response from
;             this procedure allows the query to work correctly
;
; Author    : Mike Wendling - May 22,1995
;
; Returns   : formatted string, 
;             must assign returned string to variable, as the 
;             passed in parameter is not harmed.
;
; Examples  :
;    str.a = "Try.it.." 
;    newsrch.a = WildCardQueryFormat( str.a )
;    newsrch.a = WildCardQueryFormat( "Max..")
;    newsrch.a = WildCardQueryFormat( "..Blue@Berry.Buster..")
;    newsrch.a = WildCardQueryFormat( "..@ll..")
;    newsrch.a = WildCardQueryFormat( "..Calvin..Hobbes..")
;    newsrch.a = WildCardQueryFormat( "..PARADOX..4.@..")
;    newsrch.a = WildCardQueryFormat( "..414/555-1212..")
;    newsrch.a = WildCardQueryFormat( "..414@555@1212..")
;    newsrch.a = WildCardQueryFormat( "..@@@/@@@-@@@@..")
;    newsrch.a = WildCardQueryFormat(  ".(Red+Yellow/Black)=Brown..")
;
PROC WildCardQueryFormat( str.a )
  PRIVATE proc.a, dots, atsign, pos1, pos2, pos, ch, newstr.a, orig

  proc.a = "WildCardQueryFormat"

  orig = str.a       ; original string
  newstr.a = ""      ; this is the returned value
  dots     = 2       ; ".." length
  atsign   = 1       ; "@"  length

  pos1 = SEARCH("..", str.a)
  pos2 = SEARCH("@", str.a)

  WHILE pos1 <> 0 OR pos2 <> 0
    SWITCH
      CASE pos1 = 0 AND pos2 <> 0 :  ch = atsign  pos = pos2
      CASE pos1 <> 0 AND pos2 = 0 :  ch = dots    pos = pos1
      CASE pos1 < pos2 :             ch = dots    pos = pos1
      CASE pos1 >= pos2 :            ch = atsign  pos = pos2
    ENDSWITCH

    IF ch = dots THEN
      ; we have found ".."
      IF pos = 1 THEN
         newstr.a = newstr.a + ".."
         str.a = SUBSTR( str.a, 3, 255)
      ELSE
         newstr.a = newstr.a + "\""+ SUBSTR( str.a , 1, pos-1 ) +"\"" + ".."
         str.a = SUBSTR( str.a, pos+2, 255)
      ENDIF
    ELSE
      ; we have found "@"
      IF pos = 1 THEN
         newstr.a = newstr.a + "@"
         str.a = SUBSTR( str.a, 2, 255)
      ELSE
         newstr.a = newstr.a + "\""+ SUBSTR( str.a , 1, pos-1 ) +"\"" + "@"
         str.a = SUBSTR( str.a, pos+1, 255)
      ENDIF
    ENDIF
    pos1 = SEARCH("..", str.a)   ; look for more ".."
    pos2 = SEARCH("@", str.a)    ; look for more "@"
  ENDWHILE

  IF RTRIM(str.a) <> "" THEN
    newstr.a = newstr.a + "\""+str.a+"\"" ; Finish up the rest of the string
  ENDIF

  RETURN newstr.a
ENDPROC

MESSAGE WildCardQueryFormat( "MAX.." )
n=getchar()
MESSAGE WildCardQueryFormat(  "..Salem,OR..")
n=getchar()
MESSAGE WildCardQueryFormat(  "..M/R..A")
n=getchar()
MESSAGE WildCardQueryFormat(  "..Yo-Yo..")
n=getchar()
MESSAGE WildCardQueryFormat(  "..Boo,Berry.Buster+Boo/Blue..")
n=getchar()
MESSAGE WildCardQueryFormat(  "555/111-1212")
n=getchar()
MESSAGE WildCardQueryFormat(  "..555/111-1212")
n=getchar()
MESSAGE WildCardQueryFormat(  "555/111-1212..")
n=getchar()
MESSAGE WildCardQueryFormat(  "../..")
n=getchar()
